@@ -1,20 +1,7 @@
 /*
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "ExportMenu.h"
@@ -22,7 +9,6 @@
 
 #include <KLocalizedString>
 #include <KApplicationTrader>
-#include <KRun>
 #include <KIO/ApplicationLauncherJob>
 #include <KNotificationJobUiDelegate>
 #include <KStandardShortcut>
@@ -112,7 +98,10 @@ void ExportMenu::getKServiceItems()
         const QUrl filename = mExportManager->getAutosaveFilename();
         mExportManager->doSave(filename);
         QList<QUrl> whereIs({ filename });
-        KRun::displayOpenWithDialog(whereIs, parentWidget(), true);
+        auto job = new KIO::ApplicationLauncherJob;
+        job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
+        job->setUrls({filename});
+        job->start();
     });
     addAction(openWith);
 }
