@@ -1,21 +1,8 @@
 /*
- *  Copyright 2019 David Redondo <kde@david-redondo.de>
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "SpectacleCore.h"
@@ -26,10 +13,10 @@
 #include "ShortcutActions.h"
 
 #include <KGlobalAccel>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
-#include <KRun>
 #include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/registry.h>
@@ -146,7 +133,6 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
     case StartMode::DBus:
         mCopyToClipboard = Settings::copyImageToClipboard();
         qApp->setQuitOnLastWindowClosed(false);
-        mCopyToClipboard = Settings::copyImageToClipboard();
         break;
 
     case StartMode::Background: {
@@ -239,11 +225,11 @@ void SpectacleCore::setUpShortcuts()
 {
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->openAction(), Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->fullScreenAction(), Qt::SHIFT + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->fullScreenAction(), Qt::SHIFT | Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->activeWindowAction(), Qt::META + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->activeWindowAction(), Qt::META | Qt::Key_Print);
 
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->regionAction(), Qt::META + Qt::SHIFT + Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->regionAction(), Qt::META | Qt::SHIFT | Qt::Key_Print);
 
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->currentScreenAction(), QList<QKeySequence>());
 }
@@ -384,6 +370,8 @@ void SpectacleCore::screenshotCanceled()
     mQuickEditor.reset(nullptr);
     if (mStartMode == StartMode::Gui) {
         mMainWindow->setScreenshotAndShow(QPixmap());
+    } else {
+        emit allDone();
     }
 }
 
@@ -454,7 +442,8 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
         lNotify->setDefaultAction(i18nc("Open the screenshot we just saved", "Open"));
         connect(lNotify, QOverload<uint>::of(&KNotification::activated), this, [this, theSavedAt](uint index) {
             if (index == 0) {
-                new KRun(theSavedAt, nullptr);
+                auto job = new KIO::OpenUrlJob(theSavedAt);
+                job->start();
                 QTimer::singleShot(250, this, [this] {
                     if (!mIsGuiInited || Settings::quitAfterSaveCopyExport()) {
                         emit allDone();
